"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyTheme = applyTheme;
exports.getLineNumWidth = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _constants = require("@atlaskit/theme/constants");

var _constants2 = require("./constants");

var _defaultTheme = require("./defaultTheme");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var getLineNumWidth = function getLineNumWidth(numLines) {
  if (!numLines) {
    return '1ch';
  }

  return "".concat(numLines.toFixed(0).length, "ch");
}; // applied to the main parent of the react-syntax-highlighter


exports.getLineNumWidth = getLineNumWidth;

var codeContainerStyle = function codeContainerStyle(hasLineNumbers) {
  return {
    padding: hasLineNumbers ? "".concat((0, _constants.gridSize)(), "px 0") : (0, _constants.gridSize)()
  };
};

var lineNumberStyle = function lineNumberStyle(theme) {
  return {
    // need this for margins
    fontFamily: "var(".concat(_constants2.VAR_CODE_FONT_FAMILY, ") !important"),
    // width of the line number gutter
    minWidth: "calc(".concat(theme.lineNumberWidth, " + ").concat((0, _constants.gridSize)() * 2, "px)"),
    // this needs to be important or it gets overwritten by inline styles
    fontStyle: 'normal !important',
    // this needs to be important or it gets overwritten by inline styles
    color: "".concat(theme.lineNumberColor, " !important"),
    flexShrink: 0,
    // needed to replicate existing design spec
    boxSizing: 'border-box',
    paddingRight: (0, _constants.gridSize)(),
    paddingLeft: (0, _constants.gridSize)(),
    marginRight: (0, _constants.gridSize)(),
    textAlign: 'right',
    userSelect: 'none',
    // this is to fix SSR spacing issue
    display: 'block'
  };
};

var sharedCodeStyle = function sharedCodeStyle(theme) {
  return {
    key: {
      color: theme.keywordColor,
      fontWeight: 'bolder'
    },
    keyword: {
      color: theme.keywordColor,
      fontWeight: 'bolder'
    },
    'attr-name': {
      color: theme.attributeColor
    },
    selector: {
      color: theme.selectorTagColor
    },
    comment: {
      color: theme.commentColor,
      fontFamily: "var(".concat(_constants2.VAR_CODE_FONT_FAMILY_ITALIC, ")"),
      fontStyle: 'italic'
    },
    'block-comment': {
      color: theme.commentColor,
      fontFamily: "var(".concat(_constants2.VAR_CODE_FONT_FAMILY_ITALIC, ")"),
      fontStyle: 'italic'
    },
    'function-name': {
      color: theme.sectionColor
    },
    'class-name': {
      color: theme.sectionColor
    },
    doctype: {
      color: theme.docTagColor
    },
    substr: {
      color: theme.substringColor
    },
    namespace: {
      color: theme.nameColor
    },
    builtin: {
      color: theme.builtInColor
    },
    entity: {
      color: theme.literalColor
    },
    bullet: {
      color: theme.bulletColor
    },
    code: {
      color: theme.codeColor
    },
    regex: {
      color: theme.regexpColor
    },
    symbol: {
      color: theme.symbolColor
    },
    variable: {
      color: theme.variableColor
    },
    url: {
      color: theme.linkColor
    },
    'selector-attr': {
      color: theme.selectorAttributeColor
    },
    'selector-pseudo': {
      color: theme.selectorPseudoColor
    },
    type: {
      color: theme.typeColor
    },
    string: {
      color: theme.stringColor
    },
    quote: {
      color: theme.quoteColor
    },
    tag: {
      color: theme.templateTagColor
    },
    title: {
      color: theme.titleColor
    },
    section: {
      color: theme.sectionColor
    },
    'meta-keyword': {
      color: theme.metaKeywordColor
    },
    meta: {
      color: theme.metaColor
    },
    italic: {
      fontStyle: 'italic'
    },
    bold: {
      fontWeight: 'bolder'
    },
    function: {
      color: theme.functionColor
    },
    number: {
      color: theme.numberColor
    },
    'attr-value': {
      color: theme.attributeColor
    },
    prolog: {
      color: theme.prologColor
    },
    cdata: {
      color: theme.cdataColor
    },
    punctuation: {
      color: theme.punctuationColor
    },
    property: {
      color: theme.propertyColor
    },
    constant: {
      color: theme.constantColor
    },
    deleted: {
      color: theme.deletedColor
    },
    boolean: {
      color: theme.booleanColor
    },
    char: {
      color: theme.charColor
    },
    inserted: {
      color: theme.insertedColor
    },
    operator: {
      color: theme.operatorColor
    },
    atrule: {
      color: theme.atruleColor
    },
    important: {
      color: theme.importantColor,
      fontWeight: 'bold'
    }
  };
}; // NB. applied on the 'pre' tag or equivalent


var codeStyle = function codeStyle(theme) {
  var _ref;

  return _ref = {
    fontSize: theme.codeFontSize || _constants2.CODE_FONT_SIZE,
    lineHeight: theme.codeLineHeight || _constants2.CODE_LINE_HEIGHT
  }, (0, _defineProperty2.default)(_ref, _constants2.VAR_CODE_FONT_FAMILY, (0, _constants.codeFontFamily)()), (0, _defineProperty2.default)(_ref, _constants2.VAR_CODE_FONT_FAMILY_ITALIC, "SFMono-MediumItalic, var(".concat(_constants2.VAR_CODE_FONT_FAMILY, ")")), (0, _defineProperty2.default)(_ref, "fontFamily", "var(".concat(_constants2.VAR_CODE_FONT_FAMILY, ")")), (0, _defineProperty2.default)(_ref, "backgroundColor", theme.backgroundColor), (0, _defineProperty2.default)(_ref, "color", theme.textColor), (0, _defineProperty2.default)(_ref, "borderRadius", (0, _constants.borderRadius)()), (0, _defineProperty2.default)(_ref, "display", 'flex'), (0, _defineProperty2.default)(_ref, "overflowX", 'auto'), (0, _defineProperty2.default)(_ref, "whiteSpace", 'pre'), _ref;
};

var codeBlockStyle = function codeBlockStyle(theme) {
  return _objectSpread({
    'pre[class*="language-"]': codeStyle(theme)
  }, sharedCodeStyle(theme));
};

var inlineCodeStyle = function inlineCodeStyle(theme) {
  return _objectSpread({
    'pre[class*="language-"]': _objectSpread(_objectSpread({}, codeStyle(theme)), {}, {
      padding: '2px 4px',
      display: 'inline',
      whiteSpace: 'pre-wrap'
    })
  }, sharedCodeStyle(theme));
};
/**
 * Allows us to inject external selectors into the component.
 * Used outside the normal <pre /> tag.
 */


var codeLayoutContainer = function codeLayoutContainer(theme) {
  return function (highlightedStartText, highlightedEndText, hasLineNumbers) {
    var _ref2;

    var lineNumberThemeStyle = lineNumberStyle(theme);
    return _ref2 = {}, (0, _defineProperty2.default)(_ref2, _constants2.VAR_CODE_LINE_NUMBER_BG_COLOR, theme.lineNumberBgColor), (0, _defineProperty2.default)(_ref2, '& .linenumber', _objectSpread(_objectSpread({}, lineNumberThemeStyle), {}, {
      display: 'inline-block !important'
    })), (0, _defineProperty2.default)(_ref2, '& [data-ds--code--row]', {
      display: 'block',
      paddingRight: "".concat((0, _constants.gridSize)(), "px !important"),
      marginRight: "-".concat((0, _constants.gridSize)(), "px")
    }), (0, _defineProperty2.default)(_ref2, '& [data-ds--code--row--highlight]', {
      background: "".concat(theme.highlightedLineBgColor),
      '&::before, &::after': {
        clipPath: 'inset(100%)',
        clip: 'rect(1px, 1px, 1px, 1px)',
        height: '1px',
        overflow: 'hidden',
        position: 'absolute',
        whiteSpace: 'nowrap',
        width: '1px'
      },
      '&::before': {
        content: "\", ".concat(highlightedStartText, ", \"")
      },
      '&::after': {
        content: "\", ".concat(highlightedEndText, ", \"")
      }
    }), (0, _defineProperty2.default)(_ref2, '& [data-ds--code--row--highlight] .linenumber', {
      borderLeft: "4px solid ".concat(theme.highlightedLineBorderColor),
      paddingLeft: "".concat((0, _constants.gridSize)() / 2, "px !important"),
      position: 'relative'
    }), (0, _defineProperty2.default)(_ref2, '& [data-ds--code--row--highlight] .linenumber::before', {
      content: '""',
      position: 'absolute',
      width: '4px',
      top: '-1px',
      left: '-4px',
      borderTop: "1px solid ".concat(theme.highlightedLineBorderColor)
    }), (0, _defineProperty2.default)(_ref2, '[data-ds--code--row--highlight] + [data-ds--code--row]:not([data-ds--code--row--highlight]), [data-ds--code--row]:not([data-ds--code--row--highlight]) + [data-ds--code--row--highlight]', {
      borderTop: '1px dashed transparent'
    }), (0, _defineProperty2.default)(_ref2, '[data-ds--code--row--highlight]:last-child', {
      borderBottom: '1px dashed transparent'
    }), (0, _defineProperty2.default)(_ref2, '& code:first-of-type', {
      paddingRight: "0px !important",
      backgroundImage: hasLineNumbers ? "linear-gradient(to right, var(".concat(_constants2.VAR_CODE_LINE_NUMBER_BG_COLOR, "), var(").concat(_constants2.VAR_CODE_LINE_NUMBER_BG_COLOR, ")\n        calc(").concat(theme.lineNumberWidth, " + ").concat(2 * (0, _constants.gridSize)(), "px), transparent calc(").concat(theme.lineNumberWidth, " + ").concat(2 * (0, _constants.gridSize)(), "px), transparent)") : undefined
    }), (0, _defineProperty2.default)(_ref2, '& code:last-of-type', {
      paddingRight: "".concat((0, _constants.gridSize)(), "px !important"),
      flex: '1 0 auto'
    }), _ref2;
  };
};

function applyTheme() {
  var theme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var maxLines = arguments.length > 1 ? arguments[1] : undefined;

  var newTheme = _objectSpread(_objectSpread({}, (0, _defaultTheme.defaultColors)(theme)), {}, {
    lineNumberWidth: maxLines ? getLineNumWidth(maxLines) : undefined
  }, theme);

  return {
    lineNumberStyle: lineNumberStyle(newTheme),
    codeBlockStyle: codeBlockStyle(newTheme),
    inlineCodeStyle: inlineCodeStyle(newTheme),
    codeLayoutContainer: codeLayoutContainer(newTheme),
    codeContainerStyle: codeContainerStyle
  };
}