import _extends from "@babel/runtime/helpers/extends";

/** @jsx jsx */
import { memo, useCallback } from 'react';
import { jsx } from '@emotion/core';
import { PrismAsync as SyntaxHighlighter } from 'react-syntax-highlighter';
import { normalizeLanguage } from '../supportedLanguages';
import { applyTheme } from '../themes/themeBuilder';
import { useHighlightLines } from './hooks/use-highlight';

const CodeBlock = ({
  showLineNumbers = true,
  language = 'text',
  theme = {},
  themeOverride = {},
  highlight = '',
  highlightedStartText = 'Highlight start',
  highlightedEndText = 'Highlight end',
  testId,
  text
}) => {
  // TODO look at memoising this
  const numLines = (text || '').split('\n').length;
  const {
    lineNumberStyle,
    codeBlockStyle,
    codeContainerStyle,
    codeLayoutContainer
  } = applyTheme({ ...theme,
    ...themeOverride
  }, numLines);
  const {
    getHighlightStyles,
    highlightedLines
  } = useHighlightLines({
    highlight,
    testId
  });
  const getLineProps = useCallback(line => getHighlightStyles(line, highlightedLines), [getHighlightStyles, highlightedLines]);
  const props = {
    language: normalizeLanguage(language),
    PreTag: 'span',
    style: codeBlockStyle,
    lineNumberStyle,
    showLineNumbers,
    codeTagProps: {
      style: codeContainerStyle(showLineNumbers)
    },
    // Wrap lines is needed to set styles on the line when highlighting.
    wrapLines: highlight.length > 0 || testId,
    lineProps: getLineProps
  };
  return jsx("div", {
    "data-testid": testId,
    "data-code-block": "",
    css: codeLayoutContainer(highlightedStartText, highlightedEndText, showLineNumbers)
  }, jsx(SyntaxHighlighter, _extends({
    "data-code-lang": language
  }, props), text));
};

export default /*#__PURE__*/memo(CodeBlock);